CREATE SEQUENCE cpr_id MINVALUE 1 INCREMENT 1;

CREATE TABLE campanhapromocao 
(  cpr_id smallint NOT NULL  DEFAULT nextval('cpr_id'),
   cpr_chave VARCHAR(13),
   cpr_datainclusao timestamp without time zone NOT NULL,
   cpr_ultimaatualizacao timestamp without time zone NOT NULL,
   cpr_descricao VARCHAR(254) NOT NULL,
   cpr_datainicio timestamp without time zone NOT NULL,
   cpr_datafim timestamp without time zone NOT NULL,
   cpr_tipoaplicacao VARCHAR(1) NOT NULL,
   cpr_canalaplicacao VARCHAR(1) NOT NULL,
   cpr_filialaplicacao VARCHAR(3),
   cpr_tabpreid smallint,
   cpr_valorminimo NUMERIC(12,4),
   cpr_ativo BOOLEAN NOT NULL DEFAULT true,
   cpr_permiteoutrosdescontos BOOLEAN NOT NULL,
   cpr_permissaoabaixocustoreposicao BOOLEAN,
   PRIMARY KEY(cpr_id)
);

CREATE INDEX fk_campanhapromocao_descricao ON campanhapromocao (cpr_descricao); 

ALTER TABLE campanhapromocao ADD CONSTRAINT fk_campanhapromocao_tabelapreco FOREIGN KEY (cpr_tabpreid) REFERENCES tabelapreco(tabpre_id); 

CREATE SEQUENCE cprxgat_id MINVALUE 1 INCREMENT 1;
  
CREATE TABLE campanhapromocaogatilho 
   (cprxgat_id smallint NOT NULL  DEFAULT nextval('cprxgat_id'), 
   cprxgat_chave VARCHAR(23),
   cprxgat_datainclusao timestamp without time zone NOT NULL,
   cprxgat_ultimaatualizacao timestamp without time zone NOT NULL,
   cprxgat_tipogatilho VARCHAR(1) NOT NULL,
   cprxgat_cprid smallint,
   cprxgat_cprfutchave smallint,
   cprxgat_tipoobrigatoriedade BOOLEAN NOT NULL,
   PRIMARY KEY(cprxgat_id)
);

CREATE SEQUENCE gatxpro_id MINVALUE 1 INCREMENT 1;

ALTER TABLE campanhapromocaogatilho ADD CONSTRAINT fk_campanhapromocaogatilho_campanha FOREIGN KEY (cprxgat_cprid) REFERENCES campanhapromocao(cpr_id);

CREATE TABLE gatilhoproduto 
(  gatxpro_id smallint NOT NULL  DEFAULT nextval('gatxpro_id'), 
   gatxpro_chave VARCHAR(33),
   gatxpro_datainclusao timestamp without time zone NOT NULL,
   gatxpro_ultimaatualizacao timestamp without time zone NOT NULL,
   gatxpro_quantidademinima NUMERIC(12,4),
   gatxpro_quantidademaxima NUMERIC(12,4),
   gatxpro_proid smallint,
   gatxpro_depid smallint,
   gatxpro_cl1id smallint,
   gatxpro_cl2id smallint,
   gatxpro_cl3id smallint,
   gatxpro_cl4id smallint,
   PRIMARY KEY(gatxpro_id)
);

ALTER TABLE gatilhoproduto ADD CONSTRAINT fk_campanhapromocaogatilho_produto FOREIGN KEY (gatxpro_proid) REFERENCES produto(pro_id);

ALTER TABLE gatilhoproduto ADD CONSTRAINT fk_campanhapromocaogatilho_departamento FOREIGN KEY (gatxpro_depid) REFERENCES departamento(dep_id);

ALTER TABLE gatilhoproduto ADD CONSTRAINT fk_campanhapromocaogatilho_classe1 FOREIGN KEY (gatxpro_cl1id) REFERENCES classe1(cl1_id);

ALTER TABLE gatilhoproduto ADD CONSTRAINT fk_campanhapromocaogatilho_classe2 FOREIGN KEY (gatxpro_cl2id) REFERENCES classe2(cl2_id);

ALTER TABLE gatilhoproduto ADD CONSTRAINT fk_campanhapromocaogatilho_classe3 FOREIGN KEY (gatxpro_cl3id) REFERENCES classe3(cl3_id);

ALTER TABLE gatilhoproduto ADD CONSTRAINT fk_campanhapromocaogatilho_classe4 FOREIGN KEY (gatxpro_cl4id) REFERENCES classe4(cl4_id);

CREATE SEQUENCE gatxcli_id MINVALUE 1 INCREMENT 1;

CREATE TABLE gatilhocliente 
(  gatxcli_id smallint NOT NULL  DEFAULT nextval('gatxcli_id'), 
   gatxcli_chave VARCHAR(33),
   gatxcli_datainclusao timestamp without time zone NOT NULL,
   gatxcli_ultimaatualizacao timestamp without time zone NOT NULL,
   gatxcli_parid smallint,
   gatxcli_ct1id smallint,
   gatxcli_ct2id smallint,
   gatxcli_ct3id smallint,
   PRIMARY KEY(gatxcli_id)
);

ALTER TABLE gatilhocliente ADD CONSTRAINT fk_gatilhocliente_participante FOREIGN KEY (gatxcli_parid) REFERENCES participante(par_id);

ALTER TABLE gatilhocliente ADD CONSTRAINT fk_gatilhocliente_categoria1 FOREIGN KEY (gatxcli_ct1id) REFERENCES categoria1(ct1_id);

ALTER TABLE gatilhocliente ADD CONSTRAINT fk_gatilhocliente_categoria2 FOREIGN KEY (gatxcli_ct2id) REFERENCES categoria2(ct2_id);

ALTER TABLE gatilhocliente ADD CONSTRAINT fk_gatilhocliente_categoria3 FOREIGN KEY (gatxcli_ct3id) REFERENCES categoria3(ct3_id);

CREATE SEQUENCE gatxapl_id MINVALUE 1 INCREMENT 1;

CREATE TABLE gatilhoaplicacao 
(  gatxapl_id smallint NOT NULL  DEFAULT nextval('gatxapl_id'),
   gatxapl_chave VARCHAR(33),
   gatxapl_datainclusao timestamp without time zone NOT NULL,
   gatxapl_ultimaatualizacao timestamp without time zone NOT NULL,
   gatxapl_tipoaplicacao VARCHAR(1) NOT NULL,
   gatxapl_valoraplicado NUMERIC(12,4) NOT NULL,
   gatxapl_quantidadeaplicada NUMERIC(12,4),
   gatxapl_proid smallint,
   gatxapl_depid smallint,
   gatxapl_cl1id smallint,
   gatxapl_cl2id smallint,
   gatxapl_cl3id smallint,
   gatxapl_cl4id smallint,
   gatxapl_aplicasobremultiplos VARCHAR(1),
   PRIMARY KEY(gatxapl_id)
);

ALTER TABLE gatilhoaplicacao ADD CONSTRAINT fk_gatilhoaplicacao_produto FOREIGN KEY (gatxapl_proid) REFERENCES produto(pro_id);

ALTER TABLE gatilhoaplicacao ADD CONSTRAINT fk_gatilhoaplicacao_departamento FOREIGN KEY (gatxapl_depid) REFERENCES departamento(dep_id);

ALTER TABLE gatilhoaplicacao ADD CONSTRAINT fk_gatilhoaplicacao_classe1 FOREIGN KEY (gatxapl_cl1id) REFERENCES classe1(cl1_id);

ALTER TABLE gatilhoaplicacao ADD CONSTRAINT fk_gatilhoaplicacao_classe2 FOREIGN KEY (gatxapl_cl2id) REFERENCES classe2(cl2_id);

ALTER TABLE gatilhoaplicacao ADD CONSTRAINT fk_gatilhoaplicacao_classe3 FOREIGN KEY (gatxapl_cl3id) REFERENCES classe3(cl3_id);

ALTER TABLE gatilhoaplicacao ADD CONSTRAINT fk_gatilhoaplicacao_classe4 FOREIGN KEY (gatxapl_cl4id) REFERENCES classe4(cl4_id);

CREATE SEQUENCE cupdes_id MINVALUE 1 INCREMENT 1;

CREATE TABLE cupomdesconto 
(  cupdes_id smallint NOT NULL  DEFAULT nextval('cupdes_id'),
   cupdes_chave VARCHAR(13),
   cupdes_cprid smallint NOT NULL,
   cupdes_numerocupom VARCHAR(20) NOT NULL,
   cupdes_tipoimpressao VARCHAR(1),
   cupdes_descricao VARCHAR(254) NOT NULL,
   cupdes_datainclusao timestamp without time zone NOT NULL,
   cupdes_ultimaatualizacao timestamp without time zone NOT NULL,
   cupdes_datainicio timestamp without time zone,
   cupdes_datafim timestamp without time zone,
   cupdes_numeromaximouso smallint, 
   cupdes_numeromaximousoporcliente smallint, 
   cupdes_cupati BOOLEAN NOT NULL DEFAULT true,
   PRIMARY KEY(cupdes_id)
);

ALTER TABLE cupomdesconto ADD CONSTRAINT fk_cupomdesconto_campanha FOREIGN KEY (cupdes_cprid) REFERENCES campanhapromocao(cpr_id);

CREATE UNIQUE INDEX uq_cupomdesconto_numerocupom ON cupomdesconto (cupdes_numerocupom);

CREATE SEQUENCE cupxuso_id MINVALUE 1 INCREMENT 1;

CREATE TABLE cupomdescontouso 
(  cupxuso_id smallint NOT NULL  DEFAULT nextval('cupxuso_id'),
   cupxuso_chave VARCHAR(23),
   cupxuso_datainclusao timestamp without time zone NOT NULL,
   cupxuso_ultimaatualizacao timestamp without time zone NOT NULL,
   cupxuso_parid smallint,
   cupxuso_ivechave VARCHAR(23),
   PRIMARY KEY(cupxuso_id)
);

ALTER TABLE cupomdescontouso ADD CONSTRAINT fk_cupomdescontouso_participante FOREIGN KEY (cupxuso_parid) REFERENCES participante(par_id);

select 'OK' from ambiente;

MD5:494145BEE6C6EDB24F85641681F7391A